"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.burnNft = exports.getBurnNftInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
function getBurnNftInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([['discriminator', s.u8()]], {
        description: 'BurnNftInstructionData',
    }), (value) => ({ ...value, discriminator: 29 }));
}
exports.getBurnNftInstructionDataSerializer = getBurnNftInstructionDataSerializer;
function burnNft(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const mintAccount = input.mint;
    const metadataAccount = input.metadata ??
        (0, accounts_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const ownerAccount = input.owner;
    const tokenAccountAccount = input.tokenAccount;
    const masterEditionAccountAccount = input.masterEditionAccount;
    const splTokenProgramAccount = input.splTokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    const collectionMetadataAccount = input.collectionMetadata;
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, true),
    });
    signers.push(ownerAccount);
    keys.push({
        pubkey: ownerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(ownerAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, true),
    });
    keys.push({
        pubkey: tokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccountAccount, true),
    });
    keys.push({
        pubkey: masterEditionAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(masterEditionAccountAccount, true),
    });
    keys.push({
        pubkey: splTokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(splTokenProgramAccount, false),
    });
    if (collectionMetadataAccount) {
        keys.push({
            pubkey: collectionMetadataAccount,
            isSigner: false,
            isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMetadataAccount, true),
        });
    }
    const data = getBurnNftInstructionDataSerializer(context).serialize({});
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.burnNft = burnNft;
//# sourceMappingURL=burnNft.js.map