"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deprecatedMintPrintingTokensViaToken = exports.getDeprecatedMintPrintingTokensViaTokenInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const types_1 = require("../types");
function getDeprecatedMintPrintingTokensViaTokenInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        [
            'mintPrintingTokensViaTokenArgs',
            (0, types_1.getMintPrintingTokensViaTokenArgsSerializer)(context),
        ],
    ], { description: 'DeprecatedMintPrintingTokensViaTokenInstructionData' }), (value) => ({
        ...value,
        discriminator: 8,
    }));
}
exports.getDeprecatedMintPrintingTokensViaTokenInstructionDataSerializer = getDeprecatedMintPrintingTokensViaTokenInstructionDataSerializer;
function deprecatedMintPrintingTokensViaToken(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const destinationAccount = input.destination;
    const tokenAccount = input.token;
    const oneTimePrintingAuthorizationMintAccount = input.oneTimePrintingAuthorizationMint;
    const printingMintAccount = input.printingMint;
    const burnAuthorityAccount = input.burnAuthority;
    const metadataAccount = input.metadata;
    const masterEditionAccount = input.masterEdition;
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    const rentAccount = input.rent ?? (0, umi_1.publicKey)('SysvarRent111111111111111111111111111111111');
    keys.push({
        pubkey: destinationAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(destinationAccount, true),
    });
    keys.push({
        pubkey: tokenAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccount, true),
    });
    keys.push({
        pubkey: oneTimePrintingAuthorizationMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(oneTimePrintingAuthorizationMintAccount, true),
    });
    keys.push({
        pubkey: printingMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(printingMintAccount, true),
    });
    signers.push(burnAuthorityAccount);
    keys.push({
        pubkey: burnAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(burnAuthorityAccount, false),
    });
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, false),
    });
    keys.push({
        pubkey: masterEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(masterEditionAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    keys.push({
        pubkey: rentAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(rentAccount, false),
    });
    const data = getDeprecatedMintPrintingTokensViaTokenInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.deprecatedMintPrintingTokensViaToken = deprecatedMintPrintingTokensViaToken;
//# sourceMappingURL=deprecatedMintPrintingTokensViaToken.js.map