"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.lockV1 = exports.getLockV1InstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
const types_1 = require("../types");
function getLockV1InstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['lockV1Discriminator', s.u8()],
        [
            'authorizationData',
            s.option((0, types_1.getAuthorizationDataSerializer)(context)),
        ],
    ], { description: 'LockV1InstructionData' }), (value) => ({
        ...value,
        discriminator: 46,
        lockV1Discriminator: 0,
    }));
}
exports.getLockV1InstructionDataSerializer = getLockV1InstructionDataSerializer;
function lockV1(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const authorityAccount = input.authority ?? context.identity;
    const tokenOwnerAccount = input.tokenOwner ?? {
        ...programId,
        isWritable: false,
    };
    const tokenAccount = input.token;
    const mintAccount = input.mint;
    const metadataAccount = input.metadata ??
        (0, accounts_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const editionAccount = input.edition ?? { ...programId, isWritable: false };
    const tokenRecordAccount = input.tokenRecord ?? {
        ...programId,
        isWritable: false,
    };
    const payerAccount = input.payer ?? context.payer;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    const splTokenProgramAccount = input.splTokenProgram ?? {
        ...programId,
        isWritable: false,
    };
    const authorizationRulesProgramAccount = input.authorizationRulesProgram ?? {
        ...programId,
        isWritable: false,
    };
    const authorizationRulesAccount = input.authorizationRules ?? {
        ...programId,
        isWritable: false,
    };
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    keys.push({
        pubkey: tokenOwnerAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenOwnerAccount, false),
    });
    keys.push({
        pubkey: tokenAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, false),
    });
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, true),
    });
    keys.push({
        pubkey: editionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(editionAccount, false),
    });
    keys.push({
        pubkey: tokenRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenRecordAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    keys.push({
        pubkey: splTokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(splTokenProgramAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesProgramAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesAccount, false),
    });
    const data = getLockV1InstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.lockV1 = lockV1;
//# sourceMappingURL=lockV1.js.map