"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mintNewEditionFromMasterEditionViaToken = exports.getMintNewEditionFromMasterEditionViaTokenInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const types_1 = require("../types");
function getMintNewEditionFromMasterEditionViaTokenInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        [
            'mintNewEditionFromMasterEditionViaTokenArgs',
            (0, types_1.getMintNewEditionFromMasterEditionViaTokenArgsSerializer)(context),
        ],
    ], { description: 'MintNewEditionFromMasterEditionViaTokenInstructionData' }), (value) => ({
        ...value,
        discriminator: 11,
    }));
}
exports.getMintNewEditionFromMasterEditionViaTokenInstructionDataSerializer = getMintNewEditionFromMasterEditionViaTokenInstructionDataSerializer;
function mintNewEditionFromMasterEditionViaToken(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const newMetadataAccount = input.newMetadata;
    const newEditionAccount = input.newEdition;
    const masterEditionAccount = input.masterEdition;
    const newMintAccount = input.newMint;
    const editionMarkPdaAccount = input.editionMarkPda;
    const newMintAuthorityAccount = input.newMintAuthority;
    const payerAccount = input.payer ?? context.payer;
    const tokenAccountOwnerAccount = input.tokenAccountOwner;
    const tokenAccountAccount = input.tokenAccount;
    const newMetadataUpdateAuthorityAccount = input.newMetadataUpdateAuthority;
    const metadataAccount = input.metadata;
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const rentAccount = input.rent;
    keys.push({
        pubkey: newMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newMetadataAccount, true),
    });
    keys.push({
        pubkey: newEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newEditionAccount, true),
    });
    keys.push({
        pubkey: masterEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(masterEditionAccount, true),
    });
    keys.push({
        pubkey: newMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newMintAccount, true),
    });
    keys.push({
        pubkey: editionMarkPdaAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(editionMarkPdaAccount, true),
    });
    signers.push(newMintAuthorityAccount);
    keys.push({
        pubkey: newMintAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newMintAuthorityAccount, false),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    signers.push(tokenAccountOwnerAccount);
    keys.push({
        pubkey: tokenAccountOwnerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccountOwnerAccount, false),
    });
    keys.push({
        pubkey: tokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccountAccount, false),
    });
    keys.push({
        pubkey: newMetadataUpdateAuthorityAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newMetadataUpdateAuthorityAccount, false),
    });
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    if (rentAccount) {
        keys.push({
            pubkey: rentAccount,
            isSigner: false,
            isWritable: (0, umi_1.checkForIsWritableOverride)(rentAccount, false),
        });
    }
    const data = getMintNewEditionFromMasterEditionViaTokenInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.mintNewEditionFromMasterEditionViaToken = mintNewEditionFromMasterEditionViaToken;
//# sourceMappingURL=mintNewEditionFromMasterEditionViaToken.js.map