"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateV1 = exports.getUpdateV1InstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
const types_1 = require("../types");
function getUpdateV1InstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['updateV1Discriminator', s.u8()],
        ['newUpdateAuthority', s.option(s.publicKey())],
        [
            'data',
            s.option(s.struct([
                ['name', s.string()],
                ['symbol', s.string()],
                ['uri', s.string()],
                ['sellerFeeBasisPoints', s.u16()],
                ['creators', s.option(s.array((0, types_1.getCreatorSerializer)(context)))],
            ], { description: 'Data' })),
        ],
        ['primarySaleHappened', s.option(s.bool())],
        ['isMutable', s.option(s.bool())],
        ['collection', (0, types_1.getCollectionToggleSerializer)(context)],
        ['collectionDetails', (0, types_1.getCollectionDetailsToggleSerializer)(context)],
        ['uses', (0, types_1.getUsesToggleSerializer)(context)],
        ['ruleSet', (0, types_1.getRuleSetToggleSerializer)(context)],
        [
            'authorizationData',
            s.option((0, types_1.getAuthorizationDataSerializer)(context)),
        ],
    ], { description: 'UpdateV1InstructionData' }), (value) => ({
        ...value,
        discriminator: 50,
        updateV1Discriminator: 0,
        newUpdateAuthority: value.newUpdateAuthority ?? (0, umi_1.none)(),
        data: value.data ?? (0, umi_1.none)(),
        primarySaleHappened: value.primarySaleHappened ?? (0, umi_1.none)(),
        isMutable: value.isMutable ?? (0, umi_1.none)(),
        collection: value.collection ?? (0, types_1.collectionToggle)('None'),
        collectionDetails: value.collectionDetails ?? (0, types_1.collectionDetailsToggle)('None'),
        uses: value.uses ?? (0, types_1.usesToggle)('None'),
        ruleSet: value.ruleSet ?? (0, types_1.ruleSetToggle)('None'),
        authorizationData: value.authorizationData ?? (0, umi_1.none)(),
    }));
}
exports.getUpdateV1InstructionDataSerializer = getUpdateV1InstructionDataSerializer;
function updateV1(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const authorityAccount = input.authority ?? context.identity;
    const delegateRecordAccount = input.delegateRecord ?? {
        ...programId,
        isWritable: false,
    };
    const tokenAccount = input.token ?? { ...programId, isWritable: false };
    const mintAccount = input.mint;
    const metadataAccount = input.metadata ??
        (0, accounts_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const editionAccount = input.edition ?? { ...programId, isWritable: false };
    const payerAccount = input.payer ?? context.payer;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    const authorizationRulesProgramAccount = input.authorizationRulesProgram ?? {
        ...programId,
        isWritable: false,
    };
    const authorizationRulesAccount = input.authorizationRules ?? {
        ...programId,
        isWritable: false,
    };
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    keys.push({
        pubkey: delegateRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(delegateRecordAccount, false),
    });
    keys.push({
        pubkey: tokenAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccount, false),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, false),
    });
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, true),
    });
    keys.push({
        pubkey: editionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(editionAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesProgramAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesAccount, false),
    });
    const data = getUpdateV1InstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.updateV1 = updateV1;
//# sourceMappingURL=updateV1.js.map